@@ -50,7 +50,13 @@ void ShellDBusClient::connectSignals()
     connect(m_interface, &OrgKdePlasmashellInterface::openHomeScreenRequested, this, &ShellDBusClient::openHomeScreenRequested);
     connect(m_interface, &OrgKdePlasmashellInterface::resetHomeScreenPositionRequested, this, &ShellDBusClient::resetHomeScreenPositionRequested);
     connect(m_interface, &OrgKdePlasmashellInterface::showVolumeOSDRequested, this, &ShellDBusClient::showVolumeOSDRequested);
+    connect(m_interface, &OrgKdePlasmashellInterface::openLockScreenKeypadRequested, this, &ShellDBusClient::openLockScreenKeypadRequested);
 
+    // Initial state fetch
+    updatePanelState();
+    updateIsActionDrawerOpen();
+    updateIsVolumeOSDOpen();
+    updateIsNotificationPopupDrawerOpen();
     updateDoNotDisturb();
     updateIsTaskSwitcherVisible();
 }
@@ -151,6 +157,11 @@ void ShellDBusClient::showVolumeOSD()
     m_interface->showVolumeOSD();
 }
 
+void ShellDBusClient::openLockScreenKeypad()
+{
+    m_interface->openLockScreenKeypad();
+}
+
 void ShellDBusClient::updatePanelState()
 {
     auto reply = m_interface->panelState();
@@ -158,8 +169,14 @@ void ShellDBusClient::updatePanelState()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<QString> reply = *watcher;
-        m_panelState = reply.argumentAt<0>();
-        Q_EMIT panelStateChanged();
+        QString panelState = reply.argumentAt<0>();
+
+        if (panelState != m_panelState) {
+            m_panelState = panelState;
+            Q_EMIT panelStateChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
 
@@ -170,8 +187,14 @@ void ShellDBusClient::updateDoNotDisturb()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<bool> reply = *watcher;
-        m_doNotDisturb = reply.argumentAt<0>();
-        Q_EMIT doNotDisturbChanged();
+        bool doNotDisturb = reply.argumentAt<0>();
+
+        if (doNotDisturb != m_doNotDisturb) {
+            m_doNotDisturb = doNotDisturb;
+            Q_EMIT doNotDisturbChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
 
@@ -182,8 +205,14 @@ void ShellDBusClient::updateIsActionDrawerOpen()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<bool> reply = *watcher;
-        m_isActionDrawerOpen = reply.argumentAt<0>();
-        Q_EMIT isActionDrawerOpenChanged();
+        bool isActionDrawerOpen = reply.argumentAt<0>();
+
+        if (isActionDrawerOpen != m_isActionDrawerOpen) {
+            m_isActionDrawerOpen = isActionDrawerOpen;
+            Q_EMIT isActionDrawerOpenChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
 
@@ -194,8 +223,14 @@ void ShellDBusClient::updateIsVolumeOSDOpen()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<bool> reply = *watcher;
-        m_isVolumeOSDOpen = reply.argumentAt<0>();
-        Q_EMIT isVolumeOSDOpenChanged();
+        bool isVolumeOSDOpen = reply.argumentAt<0>();
+
+        if (isVolumeOSDOpen != m_isVolumeOSDOpen) {
+            m_isVolumeOSDOpen = isVolumeOSDOpen;
+            Q_EMIT isVolumeOSDOpenChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
 
@@ -206,8 +241,14 @@ void ShellDBusClient::updateIsNotificationPopupDrawerOpen()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<bool> reply = *watcher;
-        m_isNotificationPopupDrawerOpen = reply.argumentAt<0>();
-        Q_EMIT isNotificationPopupDrawerOpenChanged();
+        bool isNotificationPopupDrawerOpen = reply.argumentAt<0>();
+
+        if (isNotificationPopupDrawerOpen != m_isNotificationPopupDrawerOpen) {
+            m_isNotificationPopupDrawerOpen = isNotificationPopupDrawerOpen;
+            Q_EMIT isNotificationPopupDrawerOpenChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
 
@@ -218,7 +259,13 @@ void ShellDBusClient::updateIsTaskSwitcherVisible()
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](auto watcher) {
         QDBusPendingReply<bool> reply = *watcher;
-        m_isTaskSwitcherVisible = reply.argumentAt<0>();
-        Q_EMIT isTaskSwitcherVisibleChanged();
+        bool isTaskSwitcherVisible = reply.argumentAt<0>();
+
+        if (isTaskSwitcherVisible != m_isTaskSwitcherVisible) {
+            m_isTaskSwitcherVisible = isTaskSwitcherVisible;
+            Q_EMIT isTaskSwitcherVisibleChanged();
+        }
+
+        watcher->deleteLater();
     });
 }
